@@ -54,7 +54,7 @@ void RootedTreeNode::setNumberOfChilds(const qint32 number)
 {
     if (number != m_nChilds){
         for (qint32 i = number; i < m_nChilds; ++i) {
-            setChild(dataStructure()->addData(""), i);
+            setChild(dataStructure()->createData("", 0), i);
         }
         m_nChilds = number;
     }
@@ -103,7 +103,7 @@ PointerPtr RootedTreeNode::setNodeParent(DataPtr parent) const
         }
     }
     if (parent.get()){
-        PointerPtr ptr = dataStructure()->addPointer(this->getData(), parent);
+        PointerPtr ptr = dataStructure()->createPointer(this->getData(), parent, 0);
         ptr->setProperty("TreeEdge", -1);
         return ptr;
     }
@@ -144,7 +144,7 @@ PointerPtr RootedTreeNode::setChild(DataPtr c, quint32 idx) const{
         }
 //      child(idx)->remove();
         if (c && c.get()){
-            PointerPtr ptr = getData()->addPointer(c);
+            PointerPtr ptr = getData()->createPointer(c);
             ptr->setProperty("TreeEdge", idx);
             return ptr;
         }
@@ -261,7 +261,7 @@ QScriptValue RootedTreeNode::children_list() const
 void RootedTreeNode::adjustPosition()
 {
     DataPtr parent = nodeParent();
-    const QRectF size = dataStructure()->document()->size();
+    const QRectF size = dataStructure()->document()->sceneRect();
     if (parent){
         qreal adjust = 0.0;
         foreach (PointerPtr p, nodeParent()->pointerList(this->getData())){
